OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "저장소를 일시적으로 사용할 수 없음",
    "Storage invalid" : "저장소가 잘못됨",
    "Unknown error" : "알 수 없는 오류",
    "All files" : "모든 파일",
    "Recent" : "최근",
    "Favorites" : "즐겨찾기",
    "File could not be found" : "파일을 찾을 수 없음",
    "Move or copy" : "이동이나 복사",
    "Download" : "다운로드",
    "Delete" : "삭제",
    "Home" : "홈",
    "Close" : "닫기",
    "Could not create folder \"{dir}\"" : "폴더 \"{dir}\"을(를) 만들 수 없음",
    "Upload cancelled." : "업로드가 취소되었습니다.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "남은 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 남아 있습니다",
    "Target folder \"{dir}\" does not exist any more" : "대상 폴더 \"{dir}\"이(가) 더 이상 존재하지 않습니다",
    "Not enough free space" : "남은 공간이 부족함",
    "Uploading …" : "업로드 중…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize}({bitrate})",
    "Target folder does not exist any more" : "대상 폴더가 더 이상 존재하지 않습니다",
    "Error when assembling chunks, status code {status}" : "조각을 모으는 중 오류 발생, 상태 코드 {status}",
    "Actions" : "작업",
    "Rename" : "이름 바꾸기",
    "Copy" : "복사",
    "Delete file" : "파일 삭제",
    "Delete folder" : "폴더 삭제",
    "Disconnect storage" : "저장소 연결 해제",
    "Unshare" : "공유 해제",
    "Could not load info for file \"{file}\"" : "파일 \"{file}\"의 정보를 가져올 수 없음",
    "Files" : "파일",
    "Details" : "자세한 정보",
    "Select" : "선택",
    "Pending" : "대기 중",
    "Unable to determine date" : "날짜를 결정할 수 없음",
    "This operation is forbidden" : "이 작업이 금지됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
    "copy" : "복사",
    "Could not copy \"{file}\", target exists" : "\"{file}\"을(를) 복사할 수 없음, 대상이 존재함",
    "Could not copy \"{file}\"" : "\"{file}\"을(를) 복사할 수 없음",
    "Copied {origin} inside {destination}" : "{origin}을(를) {destination}(으)로 복사함",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} 및 다른 파일 {nbfiles}개를 {destination}(으)로 복사함",
    "{newName} already exists" : "{newName}이(가) 이미 존재함",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\"의 이름을 변경할 수 없음, 더 이상 존재하지 않음",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "폴더 \"{dir}\" 내에 파일 \"{targetName}\"이(가) 이미 있습니다. 다른 이름을 사용하십시오.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"의 이름을 바꿀 수 없음",
    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
    "Could not create folder \"{dir}\" because it already exists" : "폴더가 이미 존재하므로 폴더 \"{dir}\"을(를) 만들 수 없음",
    "Error deleting file \"{fileName}\"." : "파일 \"{fileName}\"을(를) 삭제할 수 없습니다.",
    "No search results in other folders for {tag}{filter}{endtag}" : "다른 폴더에 {tag}{filter}{endtag} 검색 결과가 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "_%n file_::_%n files_" : ["파일 %n개"],
    "{dirs} and {files}" : "{dirs} 그리고 {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n개의 숨겨진 파일 포함"],
    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
    "New" : "새로 만들기",
    "{used} of {quota} used" : "{quota} 중 {used} 사용함",
    "{used} used" : "{used} 사용함",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "\"/\" is not allowed inside a file name." : "파일 이름에 \"/\"를 사용할 수 없습니다.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\"은 허용된 파일 형식이 아님",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner}의 저장소가 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner}의 저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}'와(과) 일치"],
    "View in folder" : "폴더에서 보기",
    "Copied!" : "복사 성공!",
    "Copy direct link (only works for users who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
    "Path" : "경로",
    "_%n byte_::_%n bytes_" : ["%n 바이트"],
    "Favorited" : "즐겨찾기에 추가됨",
    "Favorite" : "즐겨찾기",
    "New folder" : "새 폴더",
    "Upload file" : "파일 업로드",
    "Not favorited" : "즐겨찾기에 없음",
    "Remove from favorites" : "즐겨찾기에서 삭제",
    "Add to favorites" : "즐겨찾기에 추가",
    "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
    "Added to favorites" : "즐겨찾기에 추가됨",
    "Removed from favorites" : "즐겨찾기에서 삭제됨",
    "You added {file} to your favorites" : "내가 {file}을(를) 즐겨찾기에 추가함",
    "You removed {file} from your favorites" : "내가 {file}을(를) 즐겨찾기에서 삭제함",
    "File changes" : "파일 변경",
    "Created by {user}" : "{user} 님이 만듦",
    "Changed by {user}" : "{user} 님이 변경함",
    "Deleted by {user}" : "{user} 님이 삭제함",
    "Restored by {user}" : "{user} 님이 복원함",
    "Renamed by {user}" : "{user} 님이 이름을 변경함",
    "Moved by {user}" : "{user} 님이 이동함",
    "\"remote user\"" : "\"원격 사용자\"",
    "You created {file}" : "{file}을(를) 만듦",
    "{user} created {file}" : "{user} 님이 {file}을(를) 만듦",
    "{file} was created in a public folder" : "공유 폴더에 {file}이(가) 생성됨",
    "You changed {file}" : "{file}을(를) 변경함",
    "{user} changed {file}" : "{user} 님이 {file}을(를) 변경함",
    "You deleted {file}" : "{file}을(를) 삭제함",
    "{user} deleted {file}" : "{user} 님이 {file}을(를) 삭제함",
    "You restored {file}" : "내가 {file}을(를) 복원함",
    "{user} restored {file}" : "{user} 님이 {file}을(를) 복원함",
    "You renamed {oldfile} to {newfile}" : "{oldfile}을(를) {newfile}(으)로 이름을 바꿈",
    "{user} renamed {oldfile} to {newfile}" : "{user} 님이 {oldfile}을(를) {newfile}(으)로 이름을 바꿈",
    "You moved {oldfile} to {newfile}" : "{oldfile}을(를) {newfile}(으)로 이동함",
    "{user} moved {oldfile} to {newfile}" : "{user} 님이 {oldfile}을(를) {newfile}(으)로 이동함",
    "A file has been added to or removed from your <strong>favorites</strong>" : "파일이 <strong>즐겨찾기</strong>에서 추가 또는 삭제됨",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "파일이나 폴더가 <strong>변경되거나</strong> <strong>이름이 바뀜</strong>",
    "A new file or folder has been <strong>created</strong>" : "새 파일이나 폴더가 <strong>생성됨</strong>",
    "A file or folder has been <strong>deleted</strong>" : "파일이나 폴더가 <strong>삭제됨</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>즐겨찾는 파일</strong>의 생성 및 변경 사항에 대한 알림을 줄일 수 있습니다<em>(스트림에서만)</em>",
    "A file or folder has been <strong>restored</strong>" : "파일이나 폴더가 <strong>복원됨</strong>",
    "Unlimited" : "무제한",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "Accept" : "수락",
    "Change" : "변경",
    "%s used" : "%s 사용함",
    "%1$s of %2$s used" : "%2$s 중 %1$s 사용됨",
    "Settings" : "설정",
    "Show hidden files" : "숨김 파일 보이기",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">내 파일에 WebDAV로 접근</a>하려면 이 주소를 사용하십시오",
    "Toggle grid view" : "모눈 보기 전환",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "No favorites yet" : "즐겨찾는 항목 없음",
    "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
    "Tags" : "태그",
    "Deleted files" : "삭제된 파일",
    "Shares" : "공유",
    "Shared with others" : "다른 사람과 공유됨",
    "Shared with you" : "나와 공유됨",
    "Shared by link" : "링크로 공유됨",
    "Deleted shares" : "삭제된 공유",
    "Text file" : "텍스트 파일",
    "New text file.txt" : "새 텍스트 파일.txt",
    "File handling" : "파일 처리",
    "Maximum upload size" : "최대 업로드 크기",
    "max. possible: " : "최대 가능:",
    "Save" : "저장",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM을 사용 중이면 변경 사항이 적용되는 데 최대 5분 정도 걸릴 수 있습니다.",
    "Missing permissions to edit from here." : "여기에서 편집할 권한이 없습니다.",
    "Cancel upload" : "업로드 취소",
    "%s of %s used" : "%s/%s 사용함"
},
"nplurals=1; plural=0;");
